#[derive(Debug)]
#[derive(Copy)]
#[derive(Clone)]
pub enum AttributesEnum {
    BoundingRectangleColor,
    ShadowColor,
    Color,
    Clockwise,
    Filled,
    DrawBoundingRectangle,
    Opacity,
    X,
    Y,
    Width,
    Height,
    StartAngle,
    LineWidth,
    ShadowBlur,
    ShadowOffsetX,
    ShadowOffsetY,
    LineDashSize,
    LineDashGap,
    BoundingRectanglePadding,
}